# remirepo spec file for php-pecl-ahocorasick
#
# Copyright (c) 2018-2024 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-ahocorasick
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  ahocorasick
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif
# Nothing yet
%global with_tests 0%{!?_without_tests:1}

Summary:        Effective Aho-Corasick string pattern matching algorithm
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
Version:        0.0.7
Release:        6%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP and LGPLv3
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

Patch0:         https://patch-diff.githubusercontent.com/raw/ph4r05/php_aho_corasick/pull/22.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
PHP extension implementing Aho-Corasick pattern matching algorithm.

Is especially effective if there is a large database of needles
(=strings to be searched, for example virus signatures).
Another advantage is that built search structure is initialized
before search in separate call thus it can be called more times
with different haystack, saving time.

Computing Aho-Corasick in th native code (PHP extension) rather than in
a pure PHP manner gives this implementation significant performance boost.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{version} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
%patch -P0 -p1 -b .pr22

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_AHOCORASICK_VERSION/{s/.* "//;s/".*$//;p}' src/php_ahocorasick.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-ahocorasick \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-ahocorasick \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/zts-php \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{_bindir}/zts-php -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license NTS/LICENSE*}
%doc %{pecl_docdir}/%{pecl_name}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Aug 22 2024 Remi Collet <remi@remirepo.net> - 0.0.7-6
- cleanup

* Wed Dec  1 2021 Remi Collet <remi@remirepo.net> - 0.0.7-5
- rebuild

* Thu Dec  3 2020 Remi Collet <remi@remirepo.net> - 0.0.7-4
- add patch for PHP 8 from
  https://github.com/ph4r05/php_aho_corasick/pull/22

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.0.7-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.0.7-2
- rebuild for 7.4.0beta1

* Mon Jul  8 2019 Remi Collet <remi@remirepo.net> - 0.0.7-1
- update to 0.0.7

* Fri Mar 15 2019 Remi Collet <remi@remirepo.net> - 0.0.6-1
- update to 0.0.6

* Fri Mar 15 2019 Remi Collet <remi@remirepo.net> - 0.0.5-1
- update to 0.0.5
- drop patches merged upstream

* Fri Mar 15 2019 Remi Collet <remi@remirepo.net> - 0.0.4-1
- update to 0.0.4
- drop patch merged upstream
- open https://github.com/ph4r05/php_aho_corasick/pull/17 fix version
- open https://github.com/ph4r05/php_aho_corasick/pull/16 travis
- run upstream test suite added in
  https://github.com/ph4r05/php_aho_corasick/pull/13
- open https://github.com/ph4r05/php_aho_corasick/pull/18 arginfo

* Thu Mar 14 2019 Remi Collet <remi@remirepo.net> - 0.0.3-1
- update to 0.0.3
- open https://github.com/ph4r05/php_aho_corasick/pull/11
  fix error: format not a string literal and no format arguments

* Thu Feb 14 2019 Remi Collet <remi@remirepo.net> - 0.0.2-1
- update to 0.0.2

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.0.1-2
- rebuild for 7.3.0beta2 new ABI

* Sat Aug 11 2018 Remi Collet <remi@remirepo.net> - 0.0.1-1
- initial package, version 0.0.1 (beta)
